<template>
  <div class="main">
    <div class="main_header">
      <div class="header_item">
        <span class="header_label">车牌号：</span>
        <el-input v-model="search.carNumber" :size="size" clearable placeholder="请输入车牌号"></el-input>
      </div>
      <div class="header_item">
        <span class="header_label">原材料名称：</span>
        <el-input v-model="search.matName" :size="size" clearable placeholder="请输入原材料名称"></el-input>
      </div>
      <div class="header_item">
        <span class="header_label">时间范围：</span>
        <el-date-picker
            v-model="search.time"
            type="daterange"
            :default-time="['00:00:00','23:59:59']"
            clearable
            value-format="yyyy-MM-dd HH:mm:ss"
            range-separator="-"
            start-placeholder="起始时间"
            end-placeholder="结束时间">
        </el-date-picker>
      </div>
      <div class="header_item">
        <el-button icon="el-icon-search" v-if="showButton('search')" @click="searchButtonInfo(true)">查询</el-button>
      </div>
    </div>
    <div class="main_content">
      <el-table
        v-loading="loading"
        :data="dataList"
        height="100%">
        <el-table-column align="center" label="序号" width="60">
          <template #default="scope">
            <span>{{(pageNum - 1) * pageSize + scope.$index + 1}}</span>
          </template>
        </el-table-column>
        <el-table-column prop="code" label="过磅编号" align="center" width="120"></el-table-column>
        <el-table-column prop="orgname" label="业务所属机构" align="center" width="200"></el-table-column>
        <el-table-column prop="supplyorgname" label="供应单位名称" align="center" width="200"></el-table-column>
        <el-table-column prop="carnumber" label="车牌号" align="center"></el-table-column>
        <el-table-column prop="drivername" label="运输司机" align="center" ></el-table-column>
        <el-table-column prop="matname" label="原料名称" align="center"></el-table-column>
        <el-table-column prop="matmodel" label="原材料型号" align="center" width="150"></el-table-column>
        <el-table-column prop="mpoundtime" label="过毛时间" align="center"></el-table-column>
        <el-table-column prop="mpoundweight" label="毛重" align="center"></el-table-column>
        <el-table-column prop="mpoundname" label="过毛人" align="center"></el-table-column>
        <el-table-column prop="ppoundtime" label="皮重时间" align="center"></el-table-column>
        <el-table-column prop="ppoundname" label="过皮人" align="center"></el-table-column>
        <el-table-column prop="jpoundweight" label="过磅净重" align="center"></el-table-column>
        <el-table-column prop="buckleweight" label="扣重" align="center"></el-table-column>
        <el-table-column prop="mweight" label="毛重" align="center"></el-table-column>
        <el-table-column prop="pweight" label="皮重" align="center"></el-table-column>
        <el-table-column prop="jweight" label="净重" align="center"></el-table-column>
        <el-table-column prop="warename" label="入库仓名称" align="center" width="100"></el-table-column>
        <el-table-column prop="types" label="同步状态" align="center" width="100">
            <template #default="{row}">
                <div>{{row.types===1?'未同步':row.types===2?'已同步':''}}</div>
            </template>
        </el-table-column>
      </el-table>
    </div>
    <div class="main_footer">
      <el-pagination
        background
        @current-change="changePageNum"
        @size-change="changePageSize"
        :current-page="pageNum"
        :page-sizes="[10, 20, 50, 100]"
        :page-size="pageSize"
        layout="total, sizes, prev, pager, next, jumper"
        :total="total">
      </el-pagination>
    </div>
  </div>
</template>

<script>
import { buttonPinia } from '../../pinia/index';
import { changeSize } from '../../plugins/public'; // 导入节流、动态切换组件尺寸方法
  export default {
    data() {
      return {
        size: changeSize(), // 组件尺寸
        pageNum: 1,
        pageSize: 10,
        search:{},//查询条件
        total: 0,
        loading: false,
        dataList: [], //进场称重列表
      }
    },
    watch: {
      asyncVisible(bol) {
        if(!bol) {
          this.ruleForm = {};
          this.$refs.ruleForm.resetFields();
        }
      }
    },
    mounted() {
      const that = this;
      // 根据窗口大小动态修改组件尺寸
      window.onresize = () => {
        that.size = changeSize();
      }
      that.searchButtonInfo(true);
    },
    methods: {
      // 查询按钮列表信息
      searchButtonInfo(bol) {
        if(bol) {
          this.pageNum = 1;
        }
        let params = Object.assign({},this.search,{
          pageNum: this.pageNum,
          pageSize: this.pageSize
        })
        params.startTime = this.search.time&&this.search.time[0]
        params.endTime = this.search.time&&this.search.time[1]
        delete params.time
        this.loading = true;
        this.$api.Materials.searchWeighRecordsList(params).then((res) => {
          if(res.statusMsg === 'ok') {
            this.total = res.data.total;
            this.dataList = res.data.list;
          }
          this.loading = false;
        })
      },
      // 判断按钮权限信息
      showButton(str) {
        const pinia = buttonPinia();
        return pinia.$state.buttonInfo.includes(str);
      },      
      // 切换页数
      changePageNum(page) {
        this.pageNum = page;
        this.searchButtonInfo();
      },
      // 切换每页条数
      changePageSize(size) {
        this.pageSize = size;
        this.searchButtonInfo();
      }
    }
  }
</script>

<style lang="scss" scoped>
@import '../../style/layout-main.scss';
/deep/.el-color-picker__trigger{
  border-color:#1C4390;
}
/deep/.el-color-picker__color{
  border-color:#1C4390;
}
</style>